{$apptype console}

uses
  Math;

const
  EPS = 1e-7;
  
type
  TPtFloat = record
    X, Y: extended;
  end;

  TPtFloatArray = array of TPtFloat;


var
  res: TPtFloatArray;


procedure addPt(const AX, AY: extended);
begin
  SetLength(res, Length(res) + 1);
  with res[High(res)] do begin
    X := AX;
    Y := AY;
  end;
end;


procedure cross(x1, y1, x2, y2, u1, v1, u2, v2: extended);
var
  dx, dy, dxs, dys: extended;
  d: extended;
  ts, t: extended;
  xx, yy: extended;
  i: integer;
begin
  dx :=  x2 - x1;  dy :=  y2 - y1;
  dxs := u2 - u1;  dys := v2 - v1;

  d := dxs * dy - dys * dx;
  if not IsZero(d, EPS) then begin
    ts := (x1 * dy - y1 * dx - u1 * dy + v1 * dx) / d;
    if not IsZero(dx, 1e-7) then
      t := (u1 - x1 + ts * dxs) / dx
    else
      t := (v1 - y1 + ts * dys) / dy;

    if InRange(t, 0, 1) and InRange(ts, 0, 1) then begin
      xx := x1 + t * dx;
      yy := y1 + t * dy;
      for i := 0 to High(res) do
        with res[i] do
          if SameValue(xx, X, EPS) and SameValue(yy, Y, EPS) then
            Exit;
            
      addPt(xx, yy);
    end;
  end;
end;


var
  fi, fo: textfile;
  x1, y1, x2, y2, u1, v1, u2, v2: extended;
  t: extended;
begin
  AssignFile(fi, 'input.txt');
  Reset(fi);
  AssignFile(fo, 'output.txt');
  Rewrite(fo);

  Read(fi, x1, y1, x2, y2, u1, v1, u2, v2);
  Assert(InRange(x1, 1, 1e6));
  Assert(InRange(y1, 1, 1e6));
  Assert(InRange(x2, 1, 1e6));
  Assert(InRange(y2, 1, 1e6));
  Assert(InRange(u1, 1, 1e6));
  Assert(InRange(v1, 1, 1e6));
  Assert(InRange(u2, 1, 1e6));
  Assert(InRange(v2, 1, 1e6));

  t := x1;
  x1 := Min(t, x2);
  x2 := Max(t, x2);
  t := y1;
  y1 := Min(t, y2);
  y2 := Max(t, y2);

  if InRange(u1, x1, x2) and InRange(v1, y1, y2) then
    addPt(u1, v1);
  if InRange(u2, x1, x2) and InRange(v2, y1, y2) then
    addPt(u2, v2);

  cross(x1, y1, x1, y2, u1, v1, u2, v2);
  cross(x1, y2, x2, y2, u1, v1, u2, v2);
  cross(x2, y2, x2, y1, u1, v1, u2, v2);
  cross(x2, y1, x1, y1, u1, v1, u2, v2);

  if Length(res) = 2 then
    Write(fo, Norm([res[0].X - res[1].X, res[0].Y - res[1].Y]):0:2)
  else
    Write(fo, 0);

  CloseFile(fo);
  CloseFile(fi);
end.
